# Ledger

## What is Ledger

Ledger is a personal finance management app that enables users to log and track their income and expenses. Users can create entries by specifying the transaction type (income or expense), amount, category (e.g., groceries, salary, entertainment), and date. The app includes a summary screen for a quick overview of finances and a detailed transaction list for reviewing all logged entries. Users can edit or delete entries as needed, ensuring accurate record-keeping. FinanceFlow helps users stay on top of their budget with a clear and organized interface.

## The Team

[Xaver Drabik](https://www.linkedin.com/in/xaverdrabik/) & [Florian Kraushofer](https://www.linkedin.com/in/florian-kraushofer-16892b26a/)

## App Concept

### Use Case
Primary Use Case:
- Tracking and Managing Personal Finances
- Viewing Financial Summaries
- Logging Transactions
- Organizing Finances by Categories
- Financial Planning
- Monitoring Budgets

### Target Users
People who want a simple and effective way to manage their personal finances.
People who want to stay organized by tracking their income and expenses, categorizing transactions, and gaining insights into their financial habits.

Like:
- Freelancers
- Students
- Budget-Conscious Individuals
- Small Business Owners

### Mockups

![Mockup](mockup.png)
![Userflow](UserFlow.png)

## Usability Testing Plan
### Experimental Questions & Variables
1. Question: Does the user have any major issue while navigating the app?
	- IV: App navigation design (e.g., layout, menu structure, or usability features).
	- DV: User-reported issues or difficulties while navigating.
	- Methods: SEQ Question

2. Question: Does the user find Categories useful?
	- IV: Presence or design of the Categories feature.
	- DV: User perception of usefulness (e.g., measured via survey or rating).
	- Method: Likert scale How useful was it?
3. Question: Does the user find Categories?
	- IV: Visibility or accessibility of the Categories feature.
	- DV: User success in locating or using Categories.
	- Method: Task Completion Testing

4. Question: Does the icon selection affect user satisfaction?
	- IV: Icon design or selection (e.g., different icon styles or clarity).
	- DV: User satisfaction (e.g., measured via survey or rating).
	- Method: Open Question

5. Question: How long does it take for a user to add a Category?
	- IV: Process or interface for adding a Category (e.g., number of steps, clarity of instructions).
	- DV: Time taken to complete the task.
	- Method: Time till completion

6. Question: How long does it take for a user to add a Transaction?
	- IV: Process or interface for adding a Transaction (e.g., simplicity, number of fields).
	- DV: Time taken to complete the task.
	- Method: Time till completion

### Heuristic Evaluation 

1. Visibility of System Status
	- Issue: Users may not be immediately aware of changes to their balance after adding or editing a transaction, as there is no clear feedback.
	- Recommendations: Implement a visual or auditory feedback system (e.g., a confirmation message or animation or redirect to the Balance overview) to inform users when their balance updates.

2. Match Between System and the Real World
	- Issues: None
	- Recommendations: None

3. User Control and Freedom
	- Issues: Users might want to create their own categories rather than use the predefined ones.
	- Recommendations: Introduce a feature to add and delete your own categories.
4. Consistency and Standards
	- Issues: The "Your Balance" and the name of the transaction do not share the same font
	- Recommendations: Standardize all texts to use the same font, and color scheme for a cohesive user experience.

5. Error Prevention
	- Issues: Users might enter invalid data, such as symbols as the amount, without receiving a warning, leading to potential errors.
	- Recommendations: Add validation checks and warnings to prevent users from entering incorrect data, ensuring errors are caught before submission.

6. Recognition Rather Than Recall
	- Issues: Users may need to remember details about past transactions, such as categories or dates, which could increase cognitive load.
	- Recommendations: Display a detailed transaction history with categories and dates visible at all times, reducing the need for users to recall information.

7. Flexibility and Efficiency of Use
	- Issues: Users may find it time-consuming to navigate through multiple screens or steps to perform common tasks, such as adding or editing transactions.
	- Recommendations: Ensure that all frequently used actions, like adding or deleting transactions, can be completed in as few steps as possible, with clear and accessible buttons for quick access.
8. Aesthetic and Minimalist Design
	- Issues: The interface might include too many visual elements or colors, which could distract users from focusing on their primary tasks, such as managing transactions or checking their balance.
	- Recommendations: Ensure that the design remains clean and focused by using a limited color palette and removing any unnecessary decorative elements, keeping the interface visually simple and task-oriented.

9. Help Users Recognize, Diagnose, and Recover from Errors
	- Issues: Error messages may not clearly explain what went wrong or how to fix it, leaving users confused.
	- Recommendations: Provide detailed error messages in plain language, including actionable steps to resolve the issue.

10. Help and Documentation
	- Issues: Help and Documentation may be important and nice to have but out of scope for this version of the design. 
	- Recommendations: For now, focus on maintaining the clarity and simplicity of the current help documentation. If these advanced features are considered in future updates, ensure that corresponding help resources are developed to support them.


